QYILITIX PROJECT package
---------------------------


To use (package), simply do::
    
    >>> from qlytix-package import (func's)
        or
    >>> import qlytix-package
    
To install ::

    >>> pip install qlytix-package
    >>> pip install qlytix-package==(version)